@@ -19,6 +19,8 @@ struct ScreenInfo
     GnomeRRScreen *	screen;
 
     GnomeRRMode **	clone_modes;
+
+    RROutput            primary;
 };
 
 struct GnomeRRScreen
@@ -31,6 +33,8 @@ struct GnomeRRScreen
     ScreenInfo *		info;
     
     int				randr_event_base;
+    int				rr_major_version;
+    int				rr_minor_version;
     
     GnomeRRScreenChanged	callback;
     gpointer			data;
